@@ -94,7 +94,12 @@ module Network.CGI (
   , module Network.CGI.Compat
   ) where
 
-import Control.Exception.Extensible (Exception(..), SomeException, ErrorCall(..))
+#if MIN_VERSION_base(4,0,0)
+import Control.Exception
+#else
+import Control.Exception.Extensible
+#endif
+  (Exception(..), SomeException, ErrorCall(..))
 import Control.Monad (liftM)
 import Control.Monad.CatchIO (MonadCatchIO)
 import Control.Monad.Trans (MonadIO, liftIO)
